==> clean_android_design-0.0.119.tar.gz: lib/src/utils/button_widget.dart <==
import 'package:flutter/material.dart';

import 'highlight_builder.dart';

class SimpleButtonWidget extends StatelessWidget {
  final Widget child;
  final String text;
  final double width;
  final void Function() onPressed;
  final bool enabled;
  final MainAxisAlignment alignment;
  final double height;
  final Color color;
  final Color borderColor;
  final HighlightController highlightController;
  final bool takeWholeLine;

  const SimpleButtonWidget({
    Key key,
    this.text,
    this.onPressed,
    this.child,
    this.enabled = true,
    this.alignment = MainAxisAlignment.center,
    this.width = 250,
    this.height = 36,
    this.color,
    this.borderColor,
    this.highlightController,
    this.takeWholeLine = true,
  })  : assert(
            (child != null && text == null) || (child == null && text != null)),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return highlightController == null
        ? _buildMainWidget(color ?? Colors.grey[300])
        : HighlightBuilder(
            controller: highlightController,
            defaultColor: color ?? Colors.grey[300],
            builder: (context, color) => _buildMainWidget(color),
          );
  }

  Widget _buildMainWidget(Color color) {
    return Row(
      mainAxisAlignment: alignment,
      mainAxisSize: takeWholeLine ? MainAxisSize.max : MainAxisSize.min,
      children: <Widget>[
        Container(
          width: width,
          height: height,
          decoration: borderColor != null
              ? BoxDecoration(
                  border: Border.all(color: borderColor.withOpacity(0.5)),
                  borderRadius: BorderRadius.circular(18),
                  boxShadow: [
                      BoxShadow(
                        color: borderColor.withOpacity(0.5),
                        spreadRadius: 0.5,
                        blurRadius: 2,
                        offset: Offset(0, 1),
                      ),
                    ])
              : null,
          child: Material(
            borderRadius: BorderRadius.circular(18),
            color: color,
            child: InkWell(
              borderRadius: BorderRadius.circular(18),
              onTap: enabled ? onPressed : null,
              child: DefaultTextStyle(
                  style: TextStyle(
                    color: enabled ? Colors.black : Colors.grey,
                    fontSize: 15.5,
                    fontWeight: FontWeight.w500,
                  ),
                  child: Center(child: child == null ? Text(text) : child)),
            ),
          ),
        ),
      ],
    );
  }
}

==> clean_android_design-0.1.0.tar.gz: lib/src/utils/button_widget.dart <==
import 'package:flutter/material.dart';

import 'highlight_builder.dart';

class SimpleButtonWidget extends StatelessWidget {
  final Widget? child;
  final String? text;
  final double width;
  final void Function()? onPressed;
  final bool enabled;
  final MainAxisAlignment alignment;
  final double height;
  final Color? color;
  final Color? borderColor;
  final HighlightController? highlightController;
  final bool takeWholeLine;

  const SimpleButtonWidget({
    Key? key,
    this.text,
    this.onPressed,
    this.child,
    this.enabled = true,
    this.alignment = MainAxisAlignment.center,
    this.width = 250,
    this.height = 36,
    this.color,
    this.borderColor,
    this.highlightController,
    this.takeWholeLine = true,
  })  : assert(
            (child != null && text == null) || (child == null && text != null)),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return highlightController == null
        ? _buildMainWidget(color ?? Colors.grey[300])
        : HighlightBuilder(
            controller: highlightController,
            defaultColor: color ?? Colors.grey[300],
            builder: (context, color) => _buildMainWidget(color),
          );
  }

  Widget _buildMainWidget(Color? color) {
    return Row(
      mainAxisAlignment: alignment,
      mainAxisSize: takeWholeLine ? MainAxisSize.max : MainAxisSize.min,
      children: <Widget>[
        Container(
          width: width,
          height: height,
          decoration: borderColor != null
              ? BoxDecoration(
                  border: Border.all(color: borderColor!.withOpacity(0.5)),
                  borderRadius: BorderRadius.circular(18),
                  boxShadow: [
                      BoxShadow(
                        color: borderColor!.withOpacity(0.5),
                        spreadRadius: 0.5,
                        blurRadius: 2,
                        offset: Offset(0, 1),
                      ),
                    ])
              : null,
          child: Material(
            borderRadius: BorderRadius.circular(18),
            color: color,
            child: InkWell(
              borderRadius: BorderRadius.circular(18),
              onTap: enabled ? onPressed : null,
              child: DefaultTextStyle(
                  style: TextStyle(
                    color: enabled ? Colors.black : Colors.grey,
                    fontSize: 15.5,
                    fontWeight: FontWeight.w500,
                  ),
                  child: Center(child: child == null ? Text(text!) : child)),
            ),
          ),
        ),
      ],
    );
  }
}
